@@ -397,6 +397,14 @@ class Dialog:
         agi = self.agi
         return not agi.is_sighup and not agi.is_hungup
 
+    def start_recognizing(self):
+        log_debug(_('Включаем передачу голоса на распознавание.'))
+        self.recognizer.pause = False
+
+    def stop_recognizing(self):
+        log_debug(_('Отключаем передачу голоса на распознавание.'))
+        self.recognizer.pause = True
+
     @property
     def is_stopped(self):
         if self.is_closed:
@@ -777,6 +785,8 @@ class Dialog:
             self._agi_execute(commands, 'after_say_start')
         say_start_duration = self._voice_duration
 
+        self.start_recognizing()
+
         maxtime = float(script.get('maxtime', 600))
         minlength = int(script.get('minlength', 10))
         silence = int(script.get('silence', 15))
@@ -827,6 +837,8 @@ class Dialog:
                 log_debug(_('Диалог завершился до приёма данных.'))
                 break
 
+        self.stop_recognizing()
+
         if speech:
             answer = speech
             log_debug(_('Ответ: %r'), answer)
@@ -891,6 +903,8 @@ class Dialog:
             self._agi_execute(commands, 'after_say_start')
         say_start_duration = self._voice_duration
 
+        self.start_recognizing()
+
         say_silence = script.get('say_silence')
         if say_silence:
             say_silence_time = say_silence['time']
@@ -958,6 +972,9 @@ class Dialog:
                     self.say(**_make_say_params(saydata, variables))
                     _make_pause(pauses, 'after_say_attempt')
                     self._agi_execute(commands, 'after_say_attempt')
+
+        self.stop_recognizing()
+
         if not names:
             log_debug(_('Ответа нет.'))
             saydata = script.get('say_fail')
@@ -1007,6 +1024,8 @@ class Dialog:
             self._agi_execute(commands, 'after_say_start')
         say_start_duration = self._voice_duration
 
+        self.start_recognizing()
+
         say_silence = script.get('say_silence')
         if say_silence:
             say_silence_time = say_silence['time']
@@ -1074,6 +1093,9 @@ class Dialog:
                     self.say(**_make_say_params(saydata, variables))
                     _make_pause(pauses, 'after_say_attempt')
                     self._agi_execute(commands, 'after_say_attempt')
+
+        self.stop_recognizing()
+
         if not match:
             log_debug(_('Ответа нет.'))
             saydata = script.get('say_fail')
@@ -1123,6 +1145,8 @@ class Dialog:
             self._agi_execute(commands, 'after_say_start')
         say_start_duration = self._voice_duration
 
+        self.start_recognizing()
+
         say_silence = script.get('say_silence')
         if say_silence:
             say_silence_time = say_silence['time']
@@ -1189,6 +1213,9 @@ class Dialog:
                     self.say(**_make_say_params(saydata, variables))
                     _make_pause(pauses, 'after_say_attempt')
                     self._agi_execute(commands, 'after_say_attempt')
+
+        self.stop_recognizing()
+
         if not response:
             log_debug(_('Ответа нет.'))
             saydata = script.get('say_fail')
